@@ -515,6 +515,13 @@ echo "Setting up backup system cron jobs..."
 
 echo "✓ Backup system cron jobs configured"
 
+# Setup SSL certificate refresh for system services
+echo "Setting up SSL certificate refresh for system services..."
+(crontab -l 2>/dev/null; echo "# WHP System Service SSL - Refresh certificates daily at 3 AM") | crontab -
+(crontab -l 2>/dev/null; echo "0 3 * * * /usr/bin/php /root/whp/scripts/refresh-system-ssl.php >/dev/null 2>&1") | crontab -
+
+echo "✓ SSL certificate refresh cron job configured"
+
 # Setup WordPress auto-update system
 echo "Setting up WordPress auto-update system..."
 # Create log file with proper permissions
@@ -674,6 +681,8 @@ echo "12. PostgreSQL database server is running on port 5432 with root credentia
 echo "13. Adminer is available for PostgreSQL management via the WHP interface"
 echo "14. SSH/FTP log monitoring automatically blocks IPs after failed login attempts (configurable via Security Management)"
 echo "15. Log monitoring runs every 5 minutes checking /var/log/auth.log (SSH) and /var/log/proftpd/proftpd.log (FTP)"
+echo "16. SSL certificates for system services (httpd, proftpd) are automatically refreshed daily at 3 AM from HAProxy"
+echo "17. Health check endpoint available at /api/health.php for monitoring (unauthenticated, configurable thresholds)"
 echo ""
 echo "Troubleshooting:"
 echo "- Check logs in /var/log/httpd/ for Apache issues"
