@@ -24,7 +24,14 @@ if (!defined('AUTH_USER')) {
 require_once('../libs/WordPressManager.php');
 require_once('../libs/mysqlmgmt.php');
 require_once('../libs/BackupEngine.php');
+require_once('../libs/BackupHistory.php');
+require_once('../libs/BackupTarget.php');
+require_once('../libs/BackupStorage.php');
+
 use WHP\WordPressManager;
+use WHPBackup\BackupHistory;
+use WHPBackup\BackupTarget;
+use WHPBackup\BackupStorage;
 
 // Helper function for permission checking
 function check_permission($permission) {
@@ -464,14 +471,6 @@ try {
             }
 
             // Get backup information
-            require_once '../libs/BackupHistory.php';
-            require_once '../libs/BackupTarget.php';
-            require_once '../libs/BackupStorage.php';
-
-            use WHPBackup\BackupHistory;
-            use WHPBackup\BackupTarget;
-            use WHPBackup\BackupStorage;
-
             $backupHistory = new BackupHistory($db, $backupId);
             $backupData = $backupHistory->getData();
 
